Fun Commands
============

Information
-----------
Name:
  ``pyplanet.apps.contrib.funcmd``
Depends on:
  ``core.maniaplanet``
Game:
  -

Features
--------
This app enables some commands for fun interactive chatting with the players.
By default, also the Emoji Toolbar is enabled, you can disable this in //settings.

Commands
--------

Boot Me
~~~~~~~
Command:
  ``/bootme``
Parameters:
  None
Functionality:
  Send message and boot yourself from the server (kick).
Required permission:
  None.

Rage Quit
~~~~~~~~~
Command:
  ``/rq`` or ``/ragequit``
Parameters:
  None
Functionality:
  Ragequit from the server (kick).
Required permission:
  None.

AFK
~~~
Command:
  ``/afk``
Parameters:
  None
Functionality:
  Set yourself as AFK (spectator).
Required permission:
  None.

Good Game
~~~~~~~~~
Command:
  ``/gg``
Parameters:
  None
Functionality:
  Send Good Game to all players
Required permission:
  None.

Nice One
~~~~~~~~
Command:
  ``/n1``
Parameters:
  None
Functionality:
  Send Nice One to all players
Required permission:
  None.

Nice Try/Nice Time
~~~~~~~~~~~~~~~~~~
Command:
  ``/nt``
Parameters:
  None
Functionality:
  Send Nice Try or Nice Time to all players
Required permission:
  None.

Nice Shot
~~~~~~~~~
Command:
  ``/ns``
Parameters:
  None
Functionality:
  Send Nice Shot to all players
Required permission:
  None.
